@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : SRP
-Version : 1.0.28
+Version : 1.0.33
 Author  : Stefano Covino
-Date    : 13/09/2011
+Date    : 11/10/2011
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -45,15 +45,20 @@ History : (28/09/2010) First named version.
         : (30/04/2011) V. 3.9.2beta.
         : (30/04/2011) V. 3.10.0beta.
         : (13/09/2011) V. 3.10.0.
+        : (13/09/2011) V. 3.10.1b1.
+        : (22/09/2011) V. 3.10.1b2 and no more SRPPipelines.
+        : (29/09/2011) V. 3.10.1b3 and new filters.
+        : (02/10/2011) V. 3.10.1b4, genera function for list of FITS files.
+        : (11/10/2011) V. 3.10.1.
 """
 
 
 
 # import
-__all__ = ['SRPCatalogue','SRPFits','SRPFrames','SRPMath','SRPNet','SRPPipelines','SRPSpectroscopy','SRPStatistics', 
-            'SRPSystem']
+__all__ = ['SRPCatalogue','SRPFits','SRPFrames','SRPMath','SRPNet','SRPSpectroscopy','SRPStatistics', 
+            'SRPSystem','SRPTables']
 
 
 # Version
-__version__ = '3.10.0'
+__version__ = '3.10.1'
 
